@@ -9,15 +9,15 @@
 
     The behavior can be changed by subclassing the environment.
 
-    :copyright: Copyright 2008 by Armin Ronacher.
+    :copyright: (c) 2009 by the Jinja Team.
     :license: BSD.
 """
 import operator
-from types import FunctionType, MethodType, TracebackType, CodeType, \
-     FrameType, GeneratorType
 from jinja2.runtime import Undefined
 from jinja2.environment import Environment
 from jinja2.exceptions import SecurityError
+from jinja2.utils import FunctionType, MethodType, TracebackType, CodeType, \
+     FrameType, GeneratorType
 
 
 #: maximum number of items a range may produce
@@ -31,14 +31,27 @@ UNSAFE_FUNCTION_ATTRIBUTES = set(['func_closure', 'func_code', 'func_dict',
 UNSAFE_METHOD_ATTRIBUTES = set(['im_class', 'im_func', 'im_self'])
 
 
+import warnings
+
+# make sure we don't warn in python 2.6 about stuff we don't care about
+warnings.filterwarnings('ignore', 'the sets module', DeprecationWarning,
+                        module='jinja2.sandbox')
+
+
 from collections import deque
-from sets import Set, ImmutableSet
 from UserDict import UserDict, DictMixin
 from UserList import UserList
-_mutable_set_types = (ImmutableSet, Set, set)
+_mutable_set_types = (set,)
 _mutable_mapping_types = (UserDict, DictMixin, dict)
 _mutable_sequence_types = (UserList, list)
 
+# if sets is still available, register the mutable set from there as well
+try:
+    from sets import Set
+    _mutable_set_types += (Set,)
+except ImportError:
+    pass
+
 #: register Python 2.6 abstract base classes
 try:
     from collections import MutableSet, MutableMapping, MutableSequence
@@ -212,14 +225,14 @@ class SandboxedEnvironment(Environment):
             value = getattr(obj, attribute)
         except AttributeError:
             try:
-                return obj[argument]
+                return obj[attribute]
             except (TypeError, LookupError):
                 pass
         else:
             if self.is_safe_attribute(obj, attribute, value):
                 return value
             return self.unsafe_undefined(obj, attribute)
-        return self.undefined(obj=obj, name=argument)
+        return self.undefined(obj=obj, name=attribute)
 
     def unsafe_undefined(self, obj, attribute):
         """Return an undefined object for unsafe attributes."""
